@@ -1094,9 +1094,7 @@ extern "C" {
         unitIdx = INTEGER(units)[uu];
         /* Unit indices are zero-based in Fusion SDK. */
         if (unitIdx < 1 || unitIdx > maxNbrOfUnits) {
-          char s[256];
-          sprintf(s, "Argument 'units' contains an element out of range: %d", unitIdx);
-          error(s);
+          error("Argument 'units' contains an element out of range: %d", unitIdx);
         }
       }
     }
@@ -1352,9 +1350,7 @@ extern "C" {
         unitIdx = INTEGER(units)[uu];
         /* Unit indices are zero-based in Fusion SDK. */
         if (unitIdx < 1 || unitIdx > maxNbrOfUnits) {
-          char s[256];
-          sprintf(s, "Argument 'units' contains an element out of range: %d", unitIdx);
-          error(s);
+          error("Argument 'units' contains an element out of range: %d", unitIdx);
         }
       }
     }
@@ -1725,9 +1721,7 @@ extern "C" {
         unitIdx = INTEGER(units)[uu];
         /* Unit indices are zero-based in Fusion SDK. */
         if (unitIdx < 1 || unitIdx > maxNbrOfUnits) {
-          char s[256];
-          sprintf(s, "Argument 'units' contains an element out of range: %d", unitIdx);
-          error(s);
+          error("Argument 'units' contains an element out of range: %d", unitIdx);
         }
       }
     }
